import React, { FC, ReactNode } from 'react';
import { StyleProp, ViewStyle } from 'react-native';
export type Modal<P> = {
    Component?: FC<P>;
    id: string;
    props?: Partial<P>;
    style?: {
        component?: StyleProp<ViewStyle>;
        wrapper?: StyleProp<ViewStyle>;
    };
};
export type ModalId = Modal<any>['id'];
export type ModalContextType = {
    close: (modalId: ModalId) => void;
    open: <P>(modalId: ModalId, modal?: Partial<Modal<P>>) => void;
    opened: ModalId[];
    register: <P>(modal: Modal<P>) => void;
    registered: Record<ModalId, Modal<any>>;
    unregister: (modalId: ModalId) => void;
};
export declare const ModalContext: React.Context<ModalContextType>;
export declare const ModalProvider: FC<{
    children: ReactNode;
}>;
export declare function useModal<P>(id?: Modal<P>['id'], options?: Omit<Modal<P>, 'id'>): readonly [(newOptions?: Omit<Modal<P>, 'id'>) => void, () => void, {
    readonly modals: Record<string, Modal<any>>;
    readonly opened: string[];
    readonly openModal: <P_1>(modalId: string, modal?: Partial<Modal<P_1>> | undefined) => void;
    readonly closeModal: (modalId: string) => void;
    readonly registerModal: <P_2>(modal: Modal<P_2>) => void;
    readonly unregisterModal: (modalId: string) => void;
}];
export declare const openModal: (modal: Modal<any>) => void;
export declare const closeModal: (modalId: ModalId) => void;
